@@ -29,6 +29,7 @@
 #include <sys/socket.h>
 #include <arpa/inet.h>
 #include <config.h>
+#include <stdlib.h>
 
 // fastcgi is not yet implemented!!!
 #ifdef WITH_FASTCGI
@@ -103,6 +104,7 @@ namespace tnt
   }
 
   Cgi::Cgi(int argc, char* argv[])
+    : request(application)
   {
     cxxtools::Arg<const char*> componentNameArg(argc, argv, 'n', argv[0]);
     componentName = componentNameArg.getValue();
