@@ -36,7 +36,7 @@ namespace tnt
 
     public:
       virtual unsigned operator() (tnt::HttpRequest& request,
-        tnt::HttpReply& reply, cxxtools::QueryParams& qparam);
+        tnt::HttpReply& reply, tnt::QueryParams& qparam);
   };
 
 }
