@@ -106,20 +106,29 @@ namespace tnt
   }
 
   unsigned Static::operator() (tnt::HttpRequest& request,
-    tnt::HttpReply& reply, cxxtools::QueryParams& qparams)
+    tnt::HttpReply& reply, tnt::QueryParams& qparams)
   {
     return operator() (request, reply, qparams, false);
   }
 
   unsigned Static::operator() (tnt::HttpRequest& request,
-    tnt::HttpReply& reply, cxxtools::QueryParams& qparams, bool top)
+    tnt::HttpReply& reply, tnt::QueryParams& qparams, bool top)
   {
     if (!tnt::HttpRequest::checkUrl(request.getPathInfo()))
       throw tnt::HttpError(HTTP_BAD_REQUEST, "illegal url");
 
-    std::string file;
-    if (!documentRoot.empty())
-      file = documentRoot + '/';
+    std::string file = request.getArg(configDocumentRoot); // fetch document root from arguments first
+    if (file.empty())
+    {
+      if (!documentRoot.empty())
+        file = documentRoot;
+    }
+    else
+      log_debug("document root \"" << file << "\" got as argument");
+
+    if (!file.empty() && *file.rbegin() != '/')
+      file += '/';
+
     file += request.getPathInfo();
 
     log_debug("file: " << file);
@@ -167,8 +176,12 @@ namespace tnt
     }
 
     // set Content-Type
-    if (request.getArgs().size() > 0 && request.getArg(0).size() > 0)
-      reply.setContentType(request.getArg(0));
+    std::string contentType = request.getArg("ContentType");
+    if (!contentType.empty())
+    {
+      log_debug("content type is \"" << contentType << '"');
+      reply.setContentType(contentType);
+    }
     else
       setContentType(request, reply);
 
@@ -181,7 +194,7 @@ namespace tnt
     reply.setContentLengthHeader(st.st_size);
 
     // send data
-    log_info("send static file \"" << file << "\" size " << st.st_size << " bytes");
+    log_info("send file \"" << file << "\" size " << st.st_size << " bytes");
 
 #if HAVE_SENDFILE
     if (top)
