@@ -36,7 +36,8 @@ namespace tnt
       application_container,
       thread_container,
       session_container,
-      request_container
+      request_container,
+      param_container
     };
 
     enum scope_type
